# Abbreviator

Python Package to Abbreviate (product) names, using hyphenation provided by the [pyphen](https://pyphen.org/) package

## Installation

`pip install abbreviator`

## Example Usage

```
import abbreviator

abbreviator.sentence_shortener('what fantastic')
```

